/*
Berg, Curtis, Lugauer, & Mark
Demographics and Monetary Policy Shocks
File use CEX_DATA_FULL.dta to produce the consumption expenditure
data by age group
*/

clear
use CEX_DATA_FULL.dta

*************************************************************************
*Ave_Way: Defines what data we want to construct
*1= baseline consumption expenditures by age group
*2= nondurable consumption expenditures by age group
*3= homeowners/non-home owner consumption expenditures by age group
*4= Aggregate series (all age groups)
*************************************************************************

local Ave_Way = 1

*************************************************************************
*Variable Creation
*************************************************************************
//consumption expenditures
gen rtotexp_bclm = rfood+ ralcbev+ rtobacc+ rutil+ rpersca+ rhousop+ rpubtra+ rgasmo+ rentert+ rmisc+ rappar+ rowndwe+ rrendwe+ rhouseq+ rveh+ rread+ rhealth+ reduca+ rothlod
//non-durable consumption expenditures
gen rnon_durables = rfood + ralcbev +  rtobacc +  rutil +  rpersca +  rhousop +  rpubtra +  rgasmo +   rmisc + rappar + reduca + rread + rhealth

*Per person variables
foreach x of var rtotexp_bclm rnon_durables  {
gen pc_`x' = `x'/fam_size
}



**************************************************************************************
*This forst part does some general cleaning, renaming, and identifying of the variables
**************************************************************************************
	//Housing Ownership
	gen housing = .
	label var housing "1=own home, 0=not own"
	destring cutenure,replace
	replace housing = 1 if cutenure >=1 & cutenure <=3
	replace housing = 0 if cutenure >3 & cutenure <=6
	


*Quarterly Average variables
gen Ave_totexp_bclm = 0  
gen Ave_non_durables = .

foreach x in totexp_bclm non_durables {
replace Ave_`x' = pc_r`x'*3/num_months
}


*Cleaning
drop if Ave_totexp_bclm <=0
replace Ave_non_durables = . if Ave_non_durables <=0
drop if num_months ==0
drop if fincatax <=0
drop if age_ref < 25

gen agegroup = 0
replace agegroup = 1 if age_ref <35
replace agegroup = 2 if age_ref >=35 & age_ref <65
replace agegroup = 3 if age_ref >=65
	

sort time_id agegroup
if `Ave_Way' == 1 {
	collapse Ave_totexp_bclm, by(agegroup time_id)
	reshape wide Ave_totexp_bclm, i(time_id) j(agegroup)
	}
else if `Ave_Way' == 2 {
	collapse Ave_non_durables, by(agegroup time_id)
	reshape wide Ave_non_durables, i(time_id) j(agegroup)
	}
else if `Ave_Way' == 3 {
	collapse Ave_totexp_bclm, by(agegroup housing time_id)
	}
else if `Ave_Way' == 4 {
	collapse Ave_totexp_bclm , by( time_id)
	}

keep if time_id >1 & time_id <130
