/*
Berg, Curtis, Lugauer, & Mark
Demographics and Monetary Policy Shocks
File use CEX_DATA_RAW.dta and rearranges and cleans it into a file ready to analyze. 
Generates CEX_FULL_DATA.dta
*/

clear
use CEX_DATA_RAW.dta

**************************************************************************************
**************************************************************************************
**************************************************************************************
*This forst part does some general cleaning, renaming, and identifying of the variables
**************************************************************************************
**************************************************************************************
**************************************************************************************

*convert interview year and month into numeric variables
destring qintrvyr, replace
destring qintrvmo, replace

***************************************
***INCOME VARIABLES FOR 2004 and 2015 and 2016
* reflects changes in names/definitions
***************************************

replace fincatax = fincatxm if qintrvyr >=2004
replace fincbtax = fincbtxm if qintrvyr >=2004
replace tottxpdx = tottxpdm if qintrvyr >=2004
replace fjssdedx = fjssdedm if qintrvyr >=2004
replace frrdedx = frrdedm if qintrvyr >=2004
replace fgovretx = fgovretm if qintrvyr>=2004
replace intearnx = intearnm if qintrvyr >=2004
replace finincx = finincxm if qintrvyr >=2004

replace fincatax = finatxem if qintrvyr>2014
replace tottxpdx = totxest if qintrvyr>2014 

*often a variable will equal "." if this means no expenditures in this category. 
foreach v of var 	fgovretx	fincatax	fincbtax finincx intearnx	finlwt21 perslt18	fjssdedx	frrdedx	qintrvmo	qintrvyr	taxpropx	tottxpdx	totexppq	totexpcq	foodpq	foodcq	alcbevpq	alcbevcq	owndwepq	owndwecq	rendwepq	rendwecq	othlodpq	othlodcq	utilpq	utilcq	housoppq	housopcq	houseqpq	houseqcq	apparpq	apparcq	transpq	transcq	gasmopq	gasmocq	othvehpq	othvehcq	pubtrapq	pubtracq	healthpq	healthcq	entertpq	entertcq	perscapq	perscacq	readpq	readcq	educapq	educacq	tobaccpq	tobacccq	miscpq	misccq {
replace `v' = 0 if `v'<0
replace `v' = 0 if `v'==.
}


****************************************
** CEX variable newid has unique ID and time of interview.
** here we extract the unique ID component in variable CU_id
*****************************************
ssc install nsplit
nsplit newid, digits(6 1) gen(CU_id Intv_num)
label var CU_id "Unique ID by CU"

*****************************************
*********generating 4 digit years for the year variable
*****************************************
rename qintrvyr year
rename qintrvmo month

foreach num of numlist 84/96{
replace year = 1900+`num' if year == `num' 
}


/// "cq" is current quarter and "pq" is previous quarter. Marks how many months are in 
//  current quarter and how many months are in the previous quarter.  

gen cq_weight = 0
gen pq_weight = 0
replace cq_weight = 1 if month == 2 | month == 5 |month == 8 |month == 11 
replace cq_weight = 2 if month == 3 | month == 6 |month == 9 |month == 12 
replace pq_weight = 3 if month == 1 | month == 4 |month == 7 |month == 10
replace pq_weight = 2 if month == 2 | month == 5 |month == 8 |month == 11
replace pq_weight = 1 if month == 3 | month == 6 |month == 9 |month == 12

gen interview_quarter = 1
replace interview_quarter = 2 if month >3 & month <7
replace interview_quarter = 3 if month >6 & month <10
replace interview_quarter = 4 if month >9 

*keep relevant variables
*keep newid	age_ref	fam_size	fgovretx	fincatax	fincbtax	finincx intearnx finlwt21 perslt18 cutenure	fjssdedx	frrdedx	month	year	taxpropx	tottxpdx	totexppq	foodpq	alcbevpq	owndwepq	rendwepq	othlodpq	utilpq	housoppq	houseqpq	apparpq	transpq	gasmopq	othvehpq	pubtrapq	healthpq	entertpq	perscapq	readpq	educapq	tobaccpq	miscpq	CU_id	Intv_num	cq_weight	pq_weight	interview_quarter																							

*temporarily save the data which will be used below
save combined.dta, replace


**************************************************************************************
**************************************************************************************
**************************************************************************************
*The CEX has running interviews for each month and the expenditure variables reflect 
*see README for detail
**************************************************************************************
**************************************************************************************
**************************************************************************************

*rename pq variables
foreach var in totexp	food	alcbev	owndwe	rendwe	othlod	util	housop	houseq	appar	trans	gasmo	othveh	pubtra	health	entert	persca	read	educa	tobacc	misc {
rename `var'pq `var'
}

*identify quarter in which the expenditure took place
gen quarter = 4
replace quarter = interview_quarter-1 if interview_quarter>1
replace year = year-1 if interview_quarter==1

*temporarily save data 
save pq.dta, replace

clear
use combined.dta

*rename cq variables
foreach var in totexp	food	alcbev	owndwe	rendwe	othlod	util	housop	houseq	appar	trans	gasmo	othveh	pubtra	health	entert	persca	read	educa	tobacc	misc {
rename `var'cq `var'
}

*identify quarter in which the expenditure took place
gen quarter = interview_quarter

gen cq = 1

append using pq.dta
erase pq.dta

replace cq = 0 if cq ==.

*merge data with price indicies. See Appendix for descriptions of individual price index components
sort year quarter
merge m:1 year quarter using CPI.dta

* Number of months of expenditures in each observation
gen num_months = .
replace num_months = cq_weight if cq ==1
replace num_months = pq_weight if cq ==0

*** Converting to real variables ***
gen rfood = food*100/saf1
gen ralcbev = alcbev*100/saf116
gen rtobacc = tobacc*100/sega
gen rutil = util*100/sah2
gen rpersca = persca*100/sag1
gen rhousop = housop*100/sah3
gen rpubtra = pubtra*100/setg
gen rgasmo = gasmo*100/setb
gen rentert = entert*100/sa6
gen rmisc = misc*100/segd
gen rappar = appar*100/saa
gen rowndwe = owndwe*100/sah1
gen rrendwe = rendwe*100/seha
gen rhouseq = houseq*100/sah3
gen rveh = (trans-gasmo-pubtra)*100/sat1
gen rread = read*100/serg
gen rhealth = health*100/sam
gen reduca = educa*100/seeb
gen rothlod = othlod*100/sah1



sort year quarter
egen	time_id	=	group(year	quarter),	label


save CEX_DATA_FULL.dta, replace
erase combined.dta
