/*
Berg, Curtis, Lugauer, & Mark
Demographics and Monetary Policy Shocks
File use CEX_DATA_RAW.dta and rearranges and cleans it into a file ready to analyze. 
Generates CEX_FULL_MICRO_DATA.dta
*/

clear
use CEX_DATA_RAW.dta

**************************************************************************************
**************************************************************************************
**************************************************************************************
*This forst part does some general cleaning, renaming, and identifying of the variables
**************************************************************************************
**************************************************************************************
**************************************************************************************

*convert interview year and month into numeric variables
destring qintrvyr, replace
destring qintrvmo, replace


***************************************
***INCOME VARIABLES FOR 2004 and 2015 and 2016
* reflects changes in names/definitions
***************************************

replace fincatax = fincatxm if qintrvyr >=2004
replace fincbtax = fincbtxm if qintrvyr >=2004
replace tottxpdx = tottxpdm if qintrvyr >=2004
replace fjssdedx = fjssdedm if qintrvyr >=2004
replace frrdedx = frrdedm if qintrvyr >=2004
replace fgovretx = fgovretm if qintrvyr>=2004
replace intearnx = intearnm if qintrvyr >=2004
replace finincx = finincxm if qintrvyr >=2004

replace fincatax = finatxem if qintrvyr>2014
replace tottxpdx = totxest if qintrvyr>2014 

*keep relavant variables
keep newid	age_ref	fam_size	fgovretx	fincatax	fincbtax finincx intearnx	finlwt21 perslt18 bls_urbn marital1 respstat incnonw1 cutenure	fjssdedx	frrdedx	qintrvmo	qintrvyr	taxpropx	tottxpdx	totexppq	totexpcq	foodpq	foodcq	alcbevpq	alcbevcq	owndwepq	owndwecq	rendwepq	rendwecq	othlodpq	othlodcq	utilpq	utilcq	housoppq	housopcq	houseqpq	houseqcq	apparpq	apparcq	transpq	transcq	gasmopq	gasmocq	othvehpq	othvehcq	pubtrapq	pubtracq	healthpq	healthcq	entertpq	entertcq	perscapq	perscacq	readpq	readcq	educapq	educacq	tobaccpq	tobacccq	miscpq	misccq

*often a variable will equal "." if this means no expenditures in this category. 
foreach v of var 	fgovretx	fincatax	fincbtax finincx intearnx	finlwt21 perslt18	fjssdedx	frrdedx	qintrvmo	qintrvyr	taxpropx	tottxpdx	totexppq	totexpcq	foodpq	foodcq	alcbevpq	alcbevcq	owndwepq	owndwecq	rendwepq	rendwecq	othlodpq	othlodcq	utilpq	utilcq	housoppq	housopcq	houseqpq	houseqcq	apparpq	apparcq	transpq	transcq	gasmopq	gasmocq	othvehpq	othvehcq	pubtrapq	pubtracq	healthpq	healthcq	entertpq	entertcq	perscapq	perscacq	readpq	readcq	educapq	educacq	tobaccpq	tobacccq	miscpq	misccq {
replace `v' = 0 if `v'<0
replace `v' = 0 if `v'==.
}


****************************************
** CEX variable newid has unique ID and time of interview.
** here we extract the unique ID component in variable CU_id
*****************************************
ssc install nsplit
nsplit newid, digits(6 1) gen(CU_id Intv_num)
label var CU_id "Unique ID by CU"

*****************************************
*********generating 4 digit years for the year variable
*****************************************
rename qintrvyr year
rename qintrvmo month

foreach num of numlist 84/96{
replace year = 1900+`num' if year == `num' 
}

keep if year <2009
sort CU_id year

***Some redundant CU_id's (1984-1986)
by CU_id: egen max_year = max(year)
by CU_id: egen min_year = min(year)
gen d_year = max_year - min_year
gen tagdd = 0
replace tagdd = 1 if d_year >2
drop if tagdd == 1 & year < 1987

**Count interview observations : keep sample with 4
sort CU_id Intv_num
gen num = 1
by CU_id: egen sum_num = total(num)
drop if sum_num > 4 & year < 1987
drop num sum_num
gen num = 1
by CU_id: egen sum_num = total(num)
keep if sum_num == 4


/// "cq" is current quarter and "pq" is previous quarter. Marks how many months are in 
//  current quarter and how many months are in the previous quarter.  

gen cq_weight = 0
gen pq_weight = 0
replace cq_weight = 1 if month == 2 | month == 5 |month == 8 |month == 11 
replace cq_weight = 2 if month == 3 | month == 6 |month == 9 |month == 12 
replace pq_weight = 3 if month == 1 | month == 4 |month == 7 |month == 10
replace pq_weight = 2 if month == 2 | month == 5 |month == 8 |month == 11
replace pq_weight = 1 if month == 3 | month == 6 |month == 9 |month == 12

gen interview_quarter = 1
replace interview_quarter = 2 if month >3 & month <7
replace interview_quarter = 3 if month >6 & month <10
replace interview_quarter = 4 if month >9 

*keep relevant variables
*keep newid	age_ref	fam_size	fgovretx	fincatax	fincbtax	finincx intearnx finlwt21 perslt18 cutenure	fjssdedx	frrdedx	month	year	taxpropx	tottxpdx	totexppq	foodpq	alcbevpq	owndwepq	rendwepq	othlodpq	utilpq	housoppq	houseqpq	apparpq	transpq	gasmopq	othvehpq	pubtrapq	healthpq	entertpq	perscapq	readpq	educapq	tobaccpq	miscpq	CU_id	Intv_num	cq_weight	pq_weight	interview_quarter																							

*temporarily save the data which will be used below
save combined.dta, replace


**************************************************************************************
**************************************************************************************
**************************************************************************************
*The CEX has running interviews for each month and the expenditure variables reflect 
*see README for detail
**************************************************************************************
**************************************************************************************
**************************************************************************************

*rename pq variables
foreach var in totexp	food	alcbev	owndwe	rendwe	othlod	util	housop	houseq	appar	trans	gasmo	othveh	pubtra	health	entert	persca	read	educa	tobacc	misc {
rename `var'pq `var'
}

*identify quarter in which the expenditure took place
gen quarter = 4
replace quarter = interview_quarter-1 if interview_quarter>1
replace year = year-1 if interview_quarter==1

*temporarily save data 
save pq.dta, replace

clear
use combined.dta

*rename cq variables
foreach var in totexp	food	alcbev	owndwe	rendwe	othlod	util	housop	houseq	appar	trans	gasmo	othveh	pubtra	health	entert	persca	read	educa	tobacc	misc {
rename `var'cq `var'
}

*identify quarter in which the expenditure took place
gen quarter = interview_quarter

gen cq = 1

append using pq.dta
erase pq.dta

replace cq = 0 if cq ==.

*merge data with price indicies. See Appendix for descriptions of individual price index components
* Also has shocks and lagged shocks.
sort year quarter
merge m:1 year quarter using CPI_SHOCK.dta

* Number of months of expenditures in each observation
gen num_months = .
replace num_months = cq_weight if cq ==1
replace num_months = pq_weight if cq ==0

*** Converting to real variables ***
gen rfood = food*100/saf1
gen ralcbev = alcbev*100/saf116
gen rtobacc = tobacc*100/sega
gen rutil = util*100/sah2
gen rpersca = persca*100/sag1
gen rhousop = housop*100/sah3
gen rpubtra = pubtra*100/setg
gen rgasmo = gasmo*100/setb
gen rentert = entert*100/sa6
gen rmisc = misc*100/segd
gen rappar = appar*100/saa
gen rowndwe = owndwe*100/sah1
gen rrendwe = rendwe*100/seha
gen rhouseq = houseq*100/sah3
gen rveh = (trans-gasmo-pubtra)*100/sat1
gen rread = read*100/serg
gen rhealth = health*100/sam
gen reduca = educa*100/seeb
gen rothlod = othlod*100/sah1


sort year quarter
egen	time_id	=	group(year	quarter),	label

*Dropping 1984: allows 4 lags of shocks
keep if year > 1985 & year < 2009

sort CU_id Intv_num cq
// Drops observations where current interview quarter has no current consumption observations (interview months, 1, 4, 7, 10)
drop if num_months ==0 & cq==1  
// Drops if pq has less than 3 months of consumption AND it is interview 2    
drop if num_months <3 & cq ==0 & Intv_num == 2 

///Aggregating consumption by quarter consumption occurred. (ex. if interview month = 2, takes 1 month of consumption from current quarter plus the two months reported in previous quarter of next interview.)

foreach v of var totexp	food	alcbev	owndwe	rendwe	othlod	util	housop	houseq	appar	trans	gasmo	othveh	pubtra	health	entert	persca	read	educa	tobacc	misc rfood ralcbev rtobacc rutil rpersca rhousop rpubtra rgasmo rentert rmisc rappar rowndwe rrendwe rhouseq rveh rread rhealth reduca rothlod {
 

replace `v' = `v'+`v'[_n+1] if num_months<3 & Intv_num<5 & cq==1 & CU_id[_n+1]==CU_id & cq[_n+1]==0 
} 

// Dropping observations not used
drop if cq ==0 & num_months<3 
// Dropping 5th interview that does not have 3 months of current cconsumption observations (all of them, actually)
drop if Intv_num ==5 & num_months<3 

destring  bls_urbn marital1 respstat incnonw1, replace



/////////////////////////////////////

/// Demographic Characteristics

gen married = 0
label var married "0 not married, 1 married"
replace married =1 if marital1 == 1
gen notworking  = 0
label var notworking "0 working, 1 not working"
replace notworking  = 1 if incnonw1 > 0 & incnonw1 !=.
gen retired = 0
replace retired = 1 if incnonw1 == 1
label var retired "0 not retired, 1 retired"
gen born = year-age_ref 


gen age_group = 0
label var age_group "1 25-34, 2 35-64, 3 65+"
replace age_group = 1 if age_ref>24 & age_ref<35
replace age_group = 2 if age_ref>34 & age_ref <65
replace age_group = 3 if age_ref>64 

/* RESTRICTIONS on Consumption responses */
//ensuring c growth is continuous
sort CU_id Intv_num
gen tag = 0
label var tag " 0 usable, 1 not usable"
by CU_id:replace tag = 1 if Intv_num[_n-1]!=Intv_num-1 & _n>1

*Cleaning on age and food expenditures 
replace tag = 1 if age_group == 0
replace tag = 1 if rfood == 0
by CU_id: egen tag2 = max(tag)
label var tag2 "households, 0 usable, 1 not usable" 
drop if tag2 >0

* Replacing sum together since some observations lost depending on the interview time
drop num sum_num

gen num=1
by CU_id: egen sum_num = total(num)
label var sum_num "Total # Obs. per HH"
drop if sum_num <3
*tidying up
drop *pq *cq

// HH interview: 1,2,3 month of quarter
gen CU_Intv_M = 1
label var CU_Intv_M "Interview month of the quarter (ie. interviews take place on 1st, 2nd, or 3rd month of quarter"
replace CU_Intv_M = 2 if month == 2 | month == 5 |month == 8 |month == 11 
replace CU_Intv_M = 3 if month == 3 | month == 6 |month == 9 |month == 12 

save "CEX_FULL_MICRO_DATA.dta", replace
erase combined.dta
