/*
Berg, Curtis, Lugauer, & Mark
Demographics and Monetary Policy Shocks
File imports variables from Consumer Expenditure Survey and combines them into one data set (uncleaned)
Creates the file CEX_DATA_RAW.dta
*/

clear
*See README to find folder naming conventions.
global mystart "E:/saif_is_cool/Dropbox/BCLM/JMCB/New/PAPER_CEX_CODE"

****************************************************************
****************************************************************
**Import Variables for 1985-1995. See README for explanation
****************************************************************
****************************************************************

* From 1985-1994, the CEX files are in ASCII format. This calls the relevant variables for these years


*1985
cd ${mystart}/intrvw85
foreach Q of numlist 1/5 { 
infix float newid 1-8 /// CU id
float fam_size 297-298 /// family size
float age_ref 11-13 /// age of household head
str qintrvmo 1007-1008 /// interview month
str qintrvyr 1009-1010 /// interview year
float finlwt21 606-616 /// Weight on CU
///
float fincbtax 358-366 ///  total income pre-tax
float fincatax 348-356 /// total after tax income
float intearnx 818-825 /// interest earnings
float finincx 377-384 /// Finanial assets earnings
///
float tottxpdx 1161-1169 ///Total personal tax
float taxpropx 1148-1155 /// Property tax
float fjssdedx 621-628 /// social security contributions
float frrdedx 654-661	/// railroad retirement deductions
float fgovretx 339-346	/// government retirement deductions
///
float totexpcq 1243-1254 /// total expenditures this quarter
float totexppq 1231-1242	///
///
float foodcq 1267-1278 /// total food this quarter
float foodpq 1255-1266	///
///
float alcbevcq 1291-1302 /// total alcohol this quarter
float alcbevpq 1279-1290	///
///
float tobacccq  1771-1782 /// total tobacco this quarter
float tobaccpq 1759-1770	///
///
float utilcq  1435-1446 /// total utilities this quarter
float utilpq 1423-1434	///
///
float perscacq  1699-1710 /// total personal care this quarter
float perscapq 1687-1698	///
///
float housopcq  1459-1470 /// total household operations this quarter
float housoppq 1447-1458	///
///
float pubtracq 1627-1638 /// total public transportation this quarter
float pubtrapq 1615-1626	///
///
float gasmocq  1579-1590 /// total gas and motor oil this quarter
float gasmopq 1567-1578	///
///
float entertcq  1675-1686 /// total entertainment this quarter
float entertpq 1663-1674 ///
///
float misccq  1795-1806 /// total miscellaneous expenditures  this quarter
float miscpq 1783-1794	///
///
float apparcq 1507-1518 /// total apparrel  this quarter
float apparpq 1495-1506	///
///
float owndwecq 1363-1374 /// total owned dwelling expenditures this quarter
float owndwepq 1351-1362	///
///
float rendwecq  1387-1398 /// total rental payments this quarter
float rendwepq 1375-1386	///
///
float houseqcq 1483-1494 /// total house equiptment this quarter
float houseqpq 1471-1482	///
///
float transcq 1531-1542 /// total transportation this quarter
float transpq 1519-1530	///
///
float othvehcq 1603-1614 /// other vehicle
float othvehpq 1591-1602  ///
///
float readcq 1723-1734 /// total reading  this quarter
float readpq 1711-1722	///
///
float healthcq 1651-1662 /// health care
float healthpq 1639-1650	///
///
float educacq 1747-1758 /// Education
float educapq 1735-1746	///
///
float othlodcq 1411-1422 /// Other Lodging this quarter
float othlodpq 1399-1410 ///
///
str incnonw1 785 /// Reason not working
float perslt18 973-974 /// persons under 18 at home
str marital1 851 /// marital status
///
str educ_ref 266 /// Higest Education
int age2 15-17 /// Age of Spouse
str bls_urbn 61 /// Urban ==1
str cutenure 249 /// MORTGAGE INFO 
str respstat 1029 ///Completeness of income report
///
///
using "Q`Q'.txt",clear
save Q`Q', replace
}

*1986-1993

forvalues x = 86/93 {
cd ${mystart}/intrvw`x'
foreach Q of numlist 1/4 {
infix float newid 1-8 /// CU id
float fam_size 335-336 /// family size
float age_ref 11-13 /// age of household head
str qintrvmo 818-819 /// interview month
str qintrvyr 820-821 /// interview year
float finlwt21 424-434 /// Weight on CU
///
float fincbtax 396-404 ///  total income pre-tax
float fincatax 386-394 /// total after tax income
float intearnx 631-638 /// interest earnings
float finincx  415-422 /// Finanial assets earnings
///
float tottxpdx 973-981 ///Total personal tax
float taxpropx 960-967 /// Property tax
float fjssdedx 439-446 /// social security contributions
float frrdedx 472-479	/// railroad retirement deductions
float fgovretx 377-384	/// government retirement deductions
///
float totexpcq 1539-1550 /// total expenditures this quarter
float totexppq 1527-1538	///
///
float foodcq 1563-1574 /// total food this quarter
float foodpq 1551-1562	///
///
float alcbevcq 1635-1646 /// total alcohol this quarter
float alcbevpq 1623-1634	///
///
float tobacccq 2115-2126 /// total tobacco this quarter
float tobaccpq 2103-2114	///
///
float utilcq 1779-1790 /// total utilities this quarter
float utilpq 1767-1778	///
///
float perscacq 2043-2054 /// total personal care this quarter
float perscapq 2031-2042	///
///
float housopcq 1803-1814 /// total household operations this quarter
float housoppq 1791-1802	///
///
float pubtracq 1971-1982 /// total public transportation this quarter
float pubtrapq 1959-1970	///
///
float gasmocq 1923-1934 /// total gas and motor oil this quarter
float gasmopq 1911-1922	///
///
float entertcq 2019-2030 /// total entertainment this quarter
float entertpq 2007-2018 ///
///
float misccq 2139-2150 /// total miscellaneous expenditures  this quarter
float miscpq 2127-2138	///
///
float apparcq 1851-1862 /// total apparrel  this quarter
float apparpq 1839-1850	///
///
float owndwecq 1707-1718 /// total owned dwelling expenditures this quarter
float owndwepq 1695-1706	///
///
float rendwecq 1731-1742 /// total rental payments this quarter
float rendwepq 1719-1730	///
///
float houseqcq 1827-1838 /// total house equiptment this quarter
float houseqpq 1815-1826	///
///
float transcq 1875-1886 /// total transportation this quarter
float transpq 1863-1874	///
///
float othvehcq 1947-1958 /// other vehicle
float othvehpq 1935-1946 ///
///
float readcq 2067-2078 /// total reading  this quarter
float readpq 2055-2066	///
///
float healthcq 1995-2006 /// health care
float healthpq 1983-1994	///
///
float educacq 2091-2102 /// Education
float educapq 2079-2090	///
///
float othlodcq 1755-1766 /// Other Lodging this quarter
float othlodpq 1743-1754 ///
///
///
str incnonw1 604 /// Reason not working
float perslt18 784-785 /// persons under 18 at home
str marital1 673 /// marital status
///
str educ_ref 284 /// Higest Education
float age2 15-17 /// Age of Spouse
str bls_urbn 70 /// Urban ==1
str cutenure 267 /// MORTGAGE INFO 
str respstat 840 ///Completeness of income report
///
using "Q`Q'.txt",clear
save Q`Q', replace
}
}

*1994

cd ${mystart}/intrvw94
foreach Q of numlist 1/4 {
infix float newid 1-8 /// CU id
float fam_size 335-336 /// family size
float age_ref 11-13 /// age of household head
str qintrvmo 818-819 /// interview month
str qintrvyr 820-821 /// interview year
float finlwt21 424-434 /// Weight on CU
///
float fincbtax 396-404 ///  total income pre-tax
float fincatax 386-394 /// total after tax income
float intearnx 631-638 /// interest earnings
float finincx  415-422 /// Finanial assets earnings
///
float tottxpdx 973-981 ///Total personal tax
float taxpropx 960-967 /// Property tax
float fjssdedx 439-446 /// social security contributions
float frrdedx 472-479	/// railroad retirement deductions
float fgovretx 377-384	/// government retirement deductions
///
float totexpcq 1539-1550 /// total expenditures this quarter
float totexppq 1527-1538	///
///
float foodcq 1563-1574 /// total food this quarter
float foodpq 1551-1562	///
///
float alcbevcq 1683-1694 /// total alcohol this quarter
float alcbevpq 1671-1682	///
///
float tobacccq 3291-3302 /// total tobacco this quarter
float tobaccpq 3279-3290	///
///
float utilcq 1947-1958 /// total utilities this quarter
float utilpq 1935-1946	///
///
float perscacq 3219-3230 /// total personal care this quarter
float perscapq 3207-3218	///
///
float housopcq 2139-2150 /// total household operations this quarter
float housoppq 2127-2138	///
///
float pubtracq 2883-2894 /// total public transportation this quarter
float pubtrapq 2871-2882	///
///
float gasmocq 2763-2774 /// total gas and motor oil this quarter
float gasmopq 2751-2762	///
///
float entertcq 3075-3086 /// total entertainment this quarter
float entertpq 3063-3074 ///
///
float misccq 3315-3326 /// total miscellaneous expenditures  this quarter
float miscpq 3303-3314	///
///
float apparcq 2427-2438 /// total apparrel  this quarter
float apparpq 2415-2426	///
///
float owndwecq 1755-1766 /// total owned dwelling expenditures this quarter
float owndwepq 1743-1754	///
///
float rendwecq 1851-1862 /// total rental payments this quarter
float rendwepq 1839-1850	///
///
float houseqcq 2259-2270 /// total house equiptment this quarter
float houseqpq 2247-2258	///
///
float transcq 2667-2678 /// total transportation this quarter
float transpq 2655-2666	///
///
float readcq 3243-3254 /// total reading  this quarter
float readpq 3231-3242	///
///
float healthcq 2955-2966 /// health care
float healthpq 2943-2954	///
///
float educacq 3267-3278 /// Education
float educapq 3255-3266	///
///
float othlodcq 1923-1934 /// Other Lodging this quarter
float othlodpq 1911-1922 ///
///
///
str incnonw1 604 /// Reason not working
float perslt18 784-785 /// persons under 18 at home
str marital1 673 /// marital status
///
str educ_ref 284 /// Higest Education
int age2 15-17 /// Age of Spouse
str bls_urbn 70 /// Urban ==1
str cutenure 267 /// MORTGAGE INFO 
str respstat 840 ///Completeness of income report
///
using "Q`Q'.txt",clear
save Q`Q', replace
}

*1995
cd ${mystart}/intrvw95
foreach Q of numlist 1/5 {
infix float newid 1-8 /// CU id
float fam_size 335-336 /// family size
float age_ref 11-13 /// age of household head
str qintrvmo 818-819 /// interview month
str qintrvyr 820-821 /// interview year
float finlwt21 424-434 /// Weight on CU
///
float fincbtax 396-404 ///  total income pre-tax
float fincatax 386-394 /// total after tax income
float intearnx 631-638 /// interest earnings
float finincx  415-422 /// Finanial assets earnings
///
float tottxpdx 973-981 ///Total personal tax
float taxpropx 960-967 /// Property tax
float fjssdedx 439-446 /// social security contributions
float frrdedx 472-479	/// railroad retirement deductions
float fgovretx 377-384	/// government retirement deductions
///
float totexpcq 1539-1550 /// total expenditures this quarter
float totexppq 1527-1538	///
///
float foodcq 1563-1574 /// total food this quarter
float foodpq 1551-1562	///
///
float alcbevcq 1683-1694 /// total alcohol this quarter
float alcbevpq 1671-1682	///
///
float tobacccq 3291-3302 /// total tobacco this quarter
float tobaccpq 3279-3290	///
///
float utilcq 1947-1958 /// total utilities this quarter
float utilpq 1935-1946	///
///
float perscacq 3219-3230 /// total personal care this quarter
float perscapq 3207-3218	///
///
float housopcq 2139-2150 /// total household operations this quarter
float housoppq 2127-2138	///
///
float pubtracq 2883-2894 /// total public transportation this quarter
float pubtrapq 2871-2882	///
///
float gasmocq 2763-2774 /// total gas and motor oil this quarter
float gasmopq 2751-2762	///
///
float entertcq 3075-3086 /// total entertainment this quarter
float entertpq 3063-3074 ///
///
float misccq 3315-3326 /// total miscellaneous expenditures  this quarter
float miscpq 3303-3314	///
///
float apparcq 2427-2438 /// total apparrel  this quarter
float apparpq 2415-2426	///
///
float owndwecq 1755-1766 /// total owned dwelling expenditures this quarter
float owndwepq 1743-1754	///
///
float rendwecq 1851-1862 /// total rental payments this quarter
float rendwepq 1839-1850	///
///
float houseqcq 2259-2270 /// total house equiptment this quarter
float houseqpq 2247-2258	///
///
float transcq 2667-2678 /// total transportation this quarter
float transpq 2655-2666	///
///
float readcq 3243-3254 /// total reading  this quarter
float readpq 3231-3242	///
///
float healthcq 2955-2966 /// health care
float healthpq 2943-2954	///
///
float educacq 3267-3278 /// Education
float educapq 3255-3266	///
///
float othlodcq 1923-1934 /// Other Lodging this quarter
float othlodpq 1911-1922 ///
///
///
str incnonw1 604 /// Reason not working
float perslt18 784-785 /// persons under 18 at home
str marital1 673 /// marital status
///
str educ_ref 284 /// Higest Education
int age2 15-17 /// Age of Spouse
str bls_urbn 70 /// Urban ==1
str cutenure 267 /// MORTGAGE INFO 
str respstat 840 ///Completeness of income report
///
using "Q`Q'.txt",clear
save Q`Q', replace
}



****************************************************************
****************************************************************
**These next steps combine all of the data into one file
** file CEX_DATA_RAW.dta
****************************************************************
****************************************************************


*1984
use	${mystart}/intrvw84/Q1.dta	
foreach num of numlist 2/4{
append	using ${mystart}/intrvw84/Q`num'.dta 
}

rename *, lower

*Appending each file from 1985
foreach num of numlist 1/5{
append	using ${mystart}/intrvw85/Q`num'.dta 
}

*Appending each file from 1986
foreach num of numlist 2/4{
append	using ${mystart}/intrvw86/Q`num'.dta 
}

*Appending each file from 1987-1995 Q1-Q4
foreach year of numlist 87/95 {
foreach num of numlist 1/4{
append	using ${mystart}/intrvw`year'/Q`num'.dta 
}
}

*Appending 1996Q1 from the 1995 files (See README)
append	using ${mystart}/intrvw95/Q5.dta

*Appending each file from 1996-1999 Q2-Q4
foreach year of numlist 96/99 {
foreach num of numlist 2/4{
append	using ${mystart}/intrvw`year'/fmli`year'`num'.dta 
}
}

*Appending each file from 1997-1999 Q1
foreach year of numlist 97/99 {
append	using ${mystart}/intrvw`year'/fmli`year'1x.dta 
}

*Appending each file from 2000-2009 Q2-Q4
foreach year of numlist 0/9 {
foreach num of numlist 2/4{
append	using ${mystart}/intrvw0`year'/fmli0`year'`num'.dta 
}
}

*Appending each file from 2000-2009 Q1
foreach year of numlist 0/9 {
append	using ${mystart}/intrvw0`year'/fmli0`year'1x.dta 
}

*Appending each file from 2010-2015 Q2-Q4
foreach year of numlist 10/15 {
foreach num of numlist 2/4{
append	using ${mystart}/intrvw`year'/fmli`year'`num'.dta 
}
}

*Appending each file from 2010-2015 Q1
foreach year of numlist 10/15 {
append	using ${mystart}/intrvw`year'/fmli`year'1x.dta 
}

append	using ${mystart}/intrvw15/fmli161.dta

save ${mystart}/CEX_DATA_RAW.dta, replace

