/*
Berg, Curtis, Lugauer, & Mark
Demographics and Monetary Policy Shocks
File use CEX_FULL_MICRO_DATA.dta and produces Table_5.csv 
*/

clear 
eststo clear
use CEX_FULL_MICRO_DATA.dta


///SHOCK1 HFI-TRM -- SHOCK2 HFI-3MO -- SHOCK3 HFI-CMO -- SHOCK4 NAR-GBK

sort CU_id Intv_num

/*CONSUMPTION */

gen rconsumption = rowndwe + rrendwe + rveh + rhouseq + rread + rfood+ ralcbev+ rtobacc+ rutil+ rpersca+ rhousop+ rpubtra+ rgasmo+ rentert+ rmisc+ rappar + rhealth+ reduca+ rothlod

by CU_id: gen dcon = (ln(rconsumption)-ln(rconsumption[_n-1])) if _n>1

//Change in marital status
gen d_marital = 0
by CU_id: replace d_marital = 1 if married[_n-1] == 1 & married == 0
by CU_id: replace d_marital = 2 if married[_n-1] == 0 & married == 1
label var d_marital "0 no change; 1 married to unmarried; 2 unmarried to married"

//Change in famsize size
by CU_id: gen d_famsize = fam_size-fam_size[_n-1]
label var d_famsize "change in CU size"

//Change in Children size
by CU_id: gen d_children = perslt18-perslt18[_n-1]
label var d_children  "change in persons under 18"

//Change in employment status
gen d_employment = 0
replace d_employment = 1 if notworking[_n-1] == 0 & notworking == 1
replace d_employment = 2 if notworking[_n-1] == 1 & notworking == 0
label var d_employment "Change in employment status"

drop if dcon == .

gen tagW = 0

*Drop if income report is incomplete (respstat == 2)
replace tagW = 1 if respstat==2
by CU_id: egen tagW2 = max(tagW)
label var tagW2 "households, 0 usable, 1 not usable" 
drop if tagW2 >0

*dropping outlier per appendix
drop if dcon < -2.5
drop if dcon > 2.5
drop if year >2007

*Requires 2 observations
gen Sample_Obs = _n
by CU_id: egen max_sample = max(Sample_Obs)
drop if max_sample == 1


rename hfitrm_* SHOCK_1_*
rename hfi3mo_* SHOCK_2_*
rename hficmo_* SHOCK_3_*
rename nargbk_* SHOCK_4_*

local CONDITIONING "i.quarter i.d_marital d_famsize d_children fam_size  perslt18 i.d_employment i.born "
local CEX_WEIGHT "[aw=finlwt21]"


////////////MAIN THREE REGRESSIONS CEX WEIGHT//////////////////////////////////////////////////////

* Table 5 (a)
foreach j in 1 3 {
eststo clear
forvalues i = 1(1)4 {
areg dcon `CONDITIONING' SHOCK_`i'_1 SHOCK_`i'_2 SHOCK_`i'_3 SHOCK_`i'_4 SHOCK_`i'_5 SHOCK_`i'_6 SHOCK_`i'_7 SHOCK_`i'_8 `CEX_WEIGHT' if age_group == `j',absorb(CU_id) vce(cluster time_id)
eststo SHOCK_`i': lincomest -(_b[SHOCK_`i'_1]+[SHOCK_`i'_2]+[SHOCK_`i'_3]+[SHOCK_`i'_4])
}
esttab using Table_5.csv, se append  ///
refcat((1) "Table 5 (a)") mtitles   ///
noobs nonotes nostar
}



*Table 5 (b)
foreach j in 1 3 {
eststo clear
forvalues i = 1(1)4 {
areg dcon `CONDITIONING' SHOCK_`i'_1 SHOCK_`i'_2 SHOCK_`i'_3 SHOCK_`i'_4 SHOCK_`i'_5 SHOCK_`i'_6 SHOCK_`i'_7 SHOCK_`i'_8 `CEX_WEIGHT' if age_group == `j',absorb(CU_id) vce(cluster time_id)
eststo SHOCK_`i': lincomest -(_b[SHOCK_`i'_1]+[SHOCK_`i'_2]+[SHOCK_`i'_3]+[SHOCK_`i'_4]+[SHOCK_`i'_5]+[SHOCK_`i'_6]+[SHOCK_`i'_7]+[SHOCK_`i'_8])
}
esttab using Table_5.csv, se append  ///
refcat((1) "Table 5 (b) ") mtitles   ///
noobs nonotes nostar
}



