/*
Berg, Curtis, Lugauer, & Mark
Demographics and Monetary Policy Shocks
File use rscfp1989.dta, rscfp1998.dta, and rscfp2007.dta and 
produces the files Figure6_a.gph and Figure6_b.gph
*/


clear
use rscfp1989.dta
generate year = 1989
append using rscfp1998.dta
replace year = 1998 if year == .
append using rscfp2007.dta
replace year = 2007 if year == .

gen income_bclm = wageinc+ bussefarminc+ intdivinc+ kginc+ ssretinc+ transfothinc+ penacctwd

gen weight = round(wgt,1)

sort age
gen age5 = .
forvalues i = 25(5)80 {
replace age5 = `i' if age >=`i' & age < `i'+5
}
replace age5 = 80 if age>=80
label var age5 "5 year age group"

*wage income to total income
generate wage_to_income = wageinc/income_bclm

generate median_wage_to_income = .
generate mean_wage_to_income = .
label var median_wage_to_income "Median wage to income"
label var mean_wage_to_income "Mean wage to income"

foreach j in 1989 1998 2007 {
quietly forvalues i = 25(5)80 {
summarize wage_to_income [fweight=weight] if age5 == `i' & year == `j', detail
replace median_wage_to_income = r(p50) if age5 == `i' & year == `j'
}
}

foreach j in 1989 1998 2007 {
quietly forvalues i = 25(5)80 {
summarize wage_to_income [fweight=weight] if age5 == `i' & year == `j', detail
replace mean_wage_to_income = r(mean) if age5 == `i' & year == `j'
}
}

sort year age5
collapse median_wage_to_income mean_wage_to_income, by(year age5)

label var median_wage_to_income "median(wage/income)"
label var mean_wage_to_income "mean(wage/income)"

line  median_wage_to_income age5 if year == 1989 || line median_wage_to_income age5 if year == 1998 ///
|| line median_wage_to_income age5 if year == 2007

graph twoway (line  median_wage_to_income age5 if year == 1989, lcolor(black) ) ///
(line median_wage_to_income age5 if year == 1998, lcolor(red) lpattern(dash) ) ///
(line median_wage_to_income age5 if year == 2007, lcolor(gray)), ///
legend(label(1 1989) label(2 1998) label(3 2007)) xlabel(25(5)80) 

graph save Figure6_a

graph twoway (line  mean_wage_to_income age5 if year == 1989, lcolor(black) ) ///
(line mean_wage_to_income age5 if year == 1998, lcolor(red) lpattern(dash) ) ///
(line mean_wage_to_income age5 if year == 2007, lcolor(gray)), ///
legend(label(1 1989) label(2 1998) label(3 2007)) xlabel(25(5)80)
 
graph save Figure6_b
