/*
Berg, Curtis, Lugauer, & Mark
Demographics and Monetary Policy Shocks
File use rscfp1989.dta, rscfp1998.dta, and rscfp2007.dta and 
produces the data in Table 4 (see Stata output)
*/



clear
use rscfp1989.dta
generate year = 1989
append using rscfp1998.dta
replace year = 1998 if year == .
append using rscfp2007.dta
replace year = 2007 if year == .

replace wgt = wgt/5
gen weight = round(wgt,1)

sort age
gen age_group = .
replace age_group = 1 if age >=25 & age<35
replace age_group = 2 if age>=35 & age <65
replace age_group = 3 if age > 65
drop if age_group == .

gen prop_equity = houses - mrthel + oresre-resdbt+nnresre

gen LA_NW1_ = (prop_equity+stocks+stmutf+annuit)/networth
gen LA_NW2_ = (prop_equity+stocks+annuit+nmmf + bond+savbnd)/networth
label var LA_NW1_ "Long Term Assets 1 as a share of Assets"
label var LA_NW2_ "Long Term Assets 2 as a share of Assets"


sort age_group year

collapse (median) LA_NW1_ (median) LA_NW2_ [fweigh=weight], by(year age_group)
reshape wide LA_NW1_ LA_NW2_, i(age_group) j(year)

order age_group LA_NW1_1989 LA_NW1_1998 LA_NW1_2007 LA_NW2_1989 LA_NW2_1998
